@@ -13,13 +13,14 @@ logger = logging.getLogger('LithiumRestV2Client')
 
 class LithiumRestV2Client(object):
 
-    def __init__(self, community_id, client_id, login, password, object, query, batch_size):
+    def __init__(self, community_id, client_id, login, password, object, query, filter, batch_size):
         self.login = login
         self.password = password
         self.community_id = community_id
         self.client_id = client_id
         self.object = object
         self.query = query
+        self.filter = filter
         self.batch_size = batch_size
         self.session_key = self.get_session_key()
 
@@ -87,7 +88,7 @@ class LithiumRestV2Client(object):
 # function to get count
     def get_count(self):
         headers = self.build_headers()
-        query = 'SELECT+count(*)+FROM+{object}'.format(object=self.object)
+        query = 'SELECT+count(*)+FROM+{object}+{filter}'.format(object=self.object, filter=self.filter)
         resp = self.get('https://{community_id}/api/2.0/search?q={query}&restapi.session_key={sessionkey}&api.pretty_print=true'.format(
           community_id=self.community_id,
           query=query,
@@ -98,7 +99,8 @@ class LithiumRestV2Client(object):
 # function to get batch
     def get_batch(self, offset):
         headers = self.build_headers()
-        query = self.query + '+LIMIT+{limit}+OFFSET+{offset}'.format(
+        query = self.query + '+{filter}+LIMIT+{limit}+OFFSET+{offset}'.format(
+            filter=self.filter,
             limit=self.batch_size,
             offset=offset)
         resp = self.get('https://{community_id}/api/2.0/search?q={query}&restapi.session_key={sessionkey}&api.pretty_print=true'.format(
